@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -128,19 +127,23 @@ list__process_line (char     *line,
 
 
 static void
-fr_command_iso_list (FrCommand  *comm)
+list__begin (gpointer data)
 {
-	FrCommandIso *comm_iso = FR_COMMAND_ISO (comm);
+	FrCommandIso *comm = data;
 
-	g_free (comm_iso->cur_path);
-	comm_iso->cur_path = NULL;
+	g_free (comm->cur_path);
+	comm->cur_path = NULL;
+}
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
-				      list__process_line,
-				      comm);
+
+static void
+fr_command_iso_list (FrCommand *comm)
+{
+	fr_process_set_out_line_func (comm->process, list__process_line, comm);
 
 	fr_process_begin_command (comm->process, "sh");
-	fr_process_add_arg (comm->process, PRIVEXECDIR "isoinfo.sh");
+	fr_process_set_begin_func (comm->process, list__begin, comm);
+	fr_process_add_arg (comm->process, SHDIR "isoinfo.sh");
 	fr_process_add_arg (comm->process, "-i");
 	fr_process_add_arg (comm->process, comm->filename);
 	fr_process_add_arg (comm->process, "-l");
@@ -182,7 +185,7 @@ fr_command_iso_extract (FrCommand  *comm,
 
 		fr_process_begin_command (comm->process, "sh");
 		fr_process_set_working_dir (comm->process, temp_dest_dir);
-		fr_process_add_arg (comm->process, PRIVEXECDIR "isoinfo.sh");
+		fr_process_add_arg (comm->process, SHDIR "isoinfo.sh");
 		fr_process_add_arg (comm->process, "-i");
 		fr_process_add_arg (comm->process, comm->filename);
 		fr_process_add_arg (comm->process, "-x");
@@ -209,18 +212,27 @@ fr_command_iso_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_iso_get_capabilities (FrCommand  *comm,
-			         const char *mime_type)
+			         const char *mime_type,
+				 gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
-	if (is_program_in_path ("isoinfo"))
+	if (is_program_available ("isoinfo", check_command))
 		capabilities |= FR_COMMAND_CAN_READ;
 
 	return capabilities;
 }
 
 
+static const char *
+fr_command_iso_get_packages (FrCommand  *comm,
+			     const char *mime_type)
+{
+	return PACKAGES ("genisoimage");
+}
+
+
 static void
 fr_command_iso_class_init (FrCommandIsoClass *class)
 {
@@ -236,6 +248,7 @@ fr_command_iso_class_init (FrCommandIsoClass *class)
 	afc->extract          = fr_command_iso_extract;
 	afc->get_mime_types   = fr_command_iso_get_mime_types;
 	afc->get_capabilities = fr_command_iso_get_capabilities;
+	afc->get_packages     = fr_command_iso_get_packages;
 }
 
 
